pub trait ReferenceFrame:
Copy
+ Clone
+ Debug {
// Required method
fn frame_name() -> &'static str;
}Expand description
A trait for defining a reference frame (orientation).
Reference frames define the orientation of coordinate axes. Different frames represent different ways of orienting a coordinate system (e.g., aligned with an equator, an orbital plane, a horizon, etc.).
Implementing
Implement this trait for zero-sized marker types that represent different frames:
use affn::frames::ReferenceFrame;
#[derive(Debug, Copy, Clone)]
pub struct MyFrame;
impl ReferenceFrame for MyFrame {
fn frame_name() -> &'static str {
"MyFrame"
}
}Required Methods
Sourcefn frame_name() -> &'static str
fn frame_name() -> &'static str
Returns the canonical name of this reference frame.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.